@@ -1,7 +1,7 @@
 (* Example program which uses Net::Google to query Google.
  * You will need to have a Google API key in ~/.googlekey for this to work.
  * Copyright (C) 2003 Merjis Ltd.
- * $Id: google.ml,v 1.3 2003/10/16 11:03:52 rich Exp $
+ * $Id: google.ml,v 1.4 2003/12/11 17:41:52 rich Exp $
  *)
 
 open Printf
@@ -30,8 +30,5 @@ let () =
        printf "* %s\n  <URL:%s>\n\n" response#title response#url
     ) search#results;
 
-  (* Destroy the Perl interpreter. *)
-  Perl.destroy (Perl.current_interpreter ());
-
   (* Perform a full collection - good way to find GC/allocation bugs. *)
   Gc.full_major ()
