@@ -1,6 +1,6 @@
 (* Example program which uses Date::Parse.
  * Copyright (C) 2003 Merjis Ltd.
- * $Id: parsedate.ml,v 1.1 2003/11/19 16:28:22 rich Exp $
+ * $Id: parsedate.ml,v 1.2 2003/12/11 17:41:52 rich Exp $
  *)
 
 open Printf
@@ -24,8 +24,5 @@ let () =
 	      ) strings
   );
 
-  (* Destroy the Perl interpreter. *)
-  Perl.destroy (Perl.current_interpreter ());
-
   (* Perform a full collection - good way to find GC/allocation bugs. *)
   Gc.full_major ()
