@@ -1,8 +1,22 @@
-(** Wrapper around Perl [WWW::Mechanize] class.
-  *
-  * Copyright (C) 2004 Merjis Ltd.
-  *
-  * $Id: pl_WWW_Mechanize.ml,v 1.4 2005/02/13 16:33:28 rich Exp $
+(** Wrapper around Perl [WWW::Mechanize] class. *)
+(*  Copyright (C) 2003 Merjis Ltd.
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this library; see the file COPYING.  If not, write to
+    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+    Boston, MA 02111-1307, USA.
+
+    $Id: pl_WWW_Mechanize.ml,v 1.8 2008-03-01 13:02:21 rich Exp $
   *)
 
 open Perl
@@ -129,7 +143,33 @@ object (self)
   method submit () =
     call_method_void sv "submit" []
 
-  (*method submit_form ?form_number ?form_name ?fields ?button ?xy () *)
+  method submit_form ?form_number ?form_name ?fields ?button ?xy () =
+    let args = ref [] in
+    let add name f = function
+      | None -> ()
+      | Some p -> args := sv_of_string name :: f p :: !args
+    in
+    add "form_number" sv_of_int form_number;
+    add "form_name" sv_of_string form_name;
+    (match fields with
+     | None -> ()
+     | Some fields ->
+	 let hv = hv_empty () in
+	 List.iter (
+	   fun (name, value) ->
+	     hv_set hv name (sv_of_string value)
+	 ) fields;
+	 let sv = hashref hv in
+	 args := sv_of_string "fields" :: sv :: !args
+    );
+    add "button" sv_of_string button;
+    (match xy with
+     | None -> ()
+     | Some (x, y) ->
+	 args := sv_of_string "x" :: sv_of_int x ::
+	   sv_of_string "y" :: sv_of_int y :: !args);
+    let sv = call_method sv "submit_form" !args in
+    new Pl_HTTP_Response.http_response sv
 
   method success =
     let sv = call_method sv "success" [] in
@@ -187,9 +227,6 @@ object (self)
 
 end
 
-(* Not much documentation exists for the WWW::Mechanize::Link class.  As far
- * as I can see, the only documented method is #url to return the URL. XXX
- *)
 and www_mechanize_link sv =
 
 object (self)
@@ -200,6 +237,26 @@ object (self)
     let sv = call_method sv "url" [] in
     string_of_sv sv
 
+  method text =
+    let sv = call_method sv "text" [] in
+    string_of_sv sv
+
+  method name =
+    let sv = call_method sv "name" [] in
+    string_of_sv sv
+
+  method tag =
+    let sv = call_method sv "tag" [] in
+    string_of_sv sv
+
+  method base =
+    let sv = call_method sv "base" [] in
+    string_of_sv sv
+
+  method url_abs =
+    let sv = call_method sv "url_abs" [] in
+    string_of_sv sv
+
 end
 
 (* XXX Should be able to pass args to constructor of LWP::UserAgent. *)
